pub fn decode_vector(in_buf: &[u8]) -> Result<Vec<u8>>Expand description
Decode COBS-encoded data, returning output as a vector of u8.
The return value is a Result that in the Ok case is a vector of u8.
let data_cobs = b"\x04ABC\x05ghij\x04xyz";
let decode_data = cobs2::cobs::decode_vector(data_cobs);
assert_eq!(decode_data.unwrap(), b"ABC\0ghij\0xyz");